#include <fprot.h>

unsigned char my_file = 0;
int sensor;
unsigned char led = 0;

#define LED_ON()     { led = 1; digitalWrite(13, led);      }
#define LED_OFF()    { led = 0; digitalWrite(13, led);      }
#define LED_TOGGLE() { led = !led;  digitalWrite(13, led);  }

void my_tx_function(unsigned char* data, unsigned long data_len)
{
  Serial.write(data, data_len);  
}

unsigned long my_rx_function(unsigned char* data, unsigned long data_len)
{
  unsigned long read = 0;

  while (read < data_len)
  {
    if (Serial.available() > 0) {
      data[read++] = Serial.read();
    }
  }

  return read;
}

void my_delay_function(unsigned long ms)
{
  delay(ms);
}

void setup()
{
  
  pinMode(13, OUTPUT); 
  
  Serial.begin(9600);
  
  if (fprot_init(my_tx_function, my_rx_function, my_delay_function))
  {
    // AK-SDFS-UART library initialized
    
    // Close all files that may be opened before reset
    fprot_close_all();
  
    // Open a file called log.txt
    if (fprot_open("\\log.txt", FPROT_MODE_RW | FPROT_MODE_CREATE_ALWAYS, &my_file) != FPROT_NO_ERROR ||
        my_file == FPROT_INVALID_FILE)
    {

      // Indicate failure keeping the LED ON
      LED_ON();
      my_file = 0;
    }
  }
}

void loop()
{
  char str[32];
  unsigned long written;
  
  // If the file was opened
  if (my_file)
  {
    
    // Read a sensor
    sensor = analogRead(A0)/4;
    
    // Create a string to write
    sprintf(str, "Analog=%i\r\n", sensor);
    
    // Write the file with the str contents
    if (fprot_write(my_file, str, strlen(str), &written) == FPROT_NO_ERROR)
    {
      
      // If fprot_write() functions succeeds, flush the file to save
      // the data permanently
      fprot_flush(my_file);

      // Toggle the LED to indicate activity
      LED_TOGGLE();
      
    } else {
    
      // On failure, keep the led ON and set my_file = 0
      LED_ON();
      my_file = 0;
      
    }
  }
  
  // Do the above each second
  delay(10);
}

